# determine linux or mac and set ADB to point to correct binary
_UNAME=`uname -s`
if [[ "$_UNAME" == "Darwin" ]]; then
    ADB=files/adb_mac
elif [[ "$_UNAME" == "Linux" ]]; then
    ADB=files/adb_linux
else
    echo -e "\n\nCan't determinte mac or linux from uname -s output: $_UNAME\n";
    exit 1;
fi

function initialTest () {
    local RESULT
    local UNAME_A=`uname -a`
    if [[ $_UNAME == "Linux" ]]; then
        # ensure we can run 32-bit adb on a 64-bit distribution
        if [[ $UNAME_A == *x86_64* && -f $ADB ]]; then
            RESULT=`$ADB 2>&1`
            if [[ $RESULT == *No\ such\ file* ]]; then
                ERR="\n\nYou appear to be running 64-bit linux and we can't execute the 32-bit adb program."
                if [[ $UNAME_A == *Ubuntu* ]]; then
                    ERR="$ERR\nOn Ubuntu you can do 'sudo apt-get install ia32-libs' then try this script again."
                fi
                echo -e $ERR
                read -n 1 -p "Press any key to quit: "
                exit 1
            fi
        fi
        # check permission to access device
        RESULT=`$ADB devices`
        if [[ $RESULT == *permission* ]]; then
            echo -e "\n\nThere appears to be a permissions problem accessing your device"
            read -n 1 -p "Press Y to try running adb with sudo or any other key to quit: " ANSWER
            if [[ $ANSWER == "y" || $ANSWER == "Y" ]]; then
                $ADB kill-server
                RESULT=`sudo $ADB devices`
                if [[ $RESULT == *permission* ]]; then
                    echo -e "\n\nWe were unable to fix the permissions problem."
                    read -n 1 -p "Press any key to quit: "
                    exit 1
                fi
            else
                exit 1
            fi
        fi
    fi
}

# if G2X_EXIT_EARLY is set in your environment the script will exit
# before it makes any changes
# e.g.
#     % G2X_EXIT_EARLY=1 ./root.command
function checkForExitEarly () {
    if [[ -n "$G2X_EXIT_EARLY" ]]; then
        echo -e "\nExiting early, G2X_EXIT_EARLY found in environment\n";
        exit 1;
    fi
}

function ensureDevice () {
    # this is global
    devices=`$ADB devices | grep -E '(^[0-9a-f]+|emulator)'`

    if [[ $? -ne 0 ]]; then
        echo "No connected device found."
        read -p "Press Enter to quit: "
        exit 1
    fi
    if [[ `echo "$devices" | wc -l` -gt 1 ]]; then
        echo "More than one device found, can not continue."
        echo -e "\n$devices\n";
        read -p "Press Enter to quit: "
        exit 1
    fi
}

function pushAndRunPsneuter () {
    echo "Pushing temporary root exploint (psneuter) to device..."
    $ADB push files/psneuter /data/local/tmp/psneuter

    echo "Running psneuter on device..."
    $ADB shell 'cd /data/local/tmp && chmod 755 psneuter && ./psneuter'
}

function removePsneuter () {
    $ADB shell 'rm /data/local/tmp/psneuter'
}

function isRooted () {
    # remember 1 is false in shell, 0 is true
    local suInstalled=1 busyboxInstalled=1 superuserInstalled=1 result

    # adb shell 'ls ...' contains some funky characters so this
    # is more complicated than it should be :(

    result=`$ADB shell 'ls /system/bin/su >/dev/null 2>&1 && echo 0'`
    if [[ $result == *0* ]]; then
        suInstalled=0
    fi

    result=`$ADB shell 'ls /system/bin/busybox >/dev/null 2>&1 && echo 0'`
    if [[ $result == *0* ]]; then
        busyboxInstalled=0
    fi

    result=`$ADB shell 'ls /system/app/Superuser.apk >/dev/null 2>&1 && echo 0'`
    if [[ $result == *0* ]]; then
        superuserInstalled=0
    fi

    if [[ $suInstalled -eq 0 && $busyboxInstalled -eq 0 && $superuserInstalled -eq 0 ]]; then
        return 0
    else
        return 1
    fi
}
